@@ -39,9 +39,7 @@ class CollectGitPlugin(CollectorPlugin):
         """
         purl = PackageURL.from_string(comp.purl)
 
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-            f"Copying git repository from {repo_url}"
-        )
+        self.get_logger().info(f"Copying git repository from {repo_url}")
 
         source_url = f"{repo_url}/{purl.namespace}/{purl.name}"
         target_dir = self.directory_for(
