@@ -40,9 +40,7 @@ class CollectHelmPlugin(CollectorPlugin):
 
         purl = PackageURL.from_string(comp.purl)
 
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-            f"Copying helm chart from {repo_url}"
-        )
+        self.get_logger().info(f"Copying helm chart from {repo_url}")
 
         source_url = f"{repo_url}/{purl.name}"
         target_dir = self.directory_for(
@@ -79,7 +77,7 @@ class CollectHelmPlugin(CollectorPlugin):
             return Result.retry(msg)
 
         self.get_logger().info(
-            "Complete helm chart artifact copy for %s", purl.to_string()
+            "Complete helm chart artifact copy for {purl.to_string()}"
         )
 
         return Result.success()
