@@ -49,7 +49,7 @@ class CollectPypiPlugin(CollectorPlugin):
             purl.type, repo_url, subdir=f"{purl.name}_{purl.version}"
         )
 
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
+        self.get_logger().info(
             f"Copying pypi artifact {purl.name}:{purl.version} from {repo_url} to {target_dir}"
         )
 
@@ -72,7 +72,7 @@ class CollectPypiPlugin(CollectorPlugin):
 
         result = self.run_command(command, password_list)
         if result.returncode != 0:
-            self.get_logger().error(  # pylint: disable=logging-fstring-interpolation
+            self.get_logger().error(
                 f"Failed to download {purl.name} version {purl.version} binary"
             )
             got_binary = False
@@ -81,7 +81,7 @@ class CollectPypiPlugin(CollectorPlugin):
 
         result = self.run_command(command, password_list)
         if result.returncode != 0:
-            self.get_logger().error(  # pylint: disable=logging-fstring-interpolation
+            self.get_logger().error(
                 f"Failed to download {purl.name} version {purl.version} source"
             )
             if not got_binary:
