@@ -51,13 +51,13 @@ class CollectRawPlugin(CollectorPlugin):
             if not Path(source_file).is_file():
                 return Result.fail(f"Unable to locate file {source_file}")
 
-            self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
+            self.get_logger().info(
                 f"Copying file from {source_file} to directory {target_dir}"
             )
             shutil.copy(source_file, target_dir)
             return Result.success()
 
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
+        self.get_logger().info(
             f"Downloading from {source_url + file_name} to file {target_dir + file_name}"
         )
         download_creds = None
