@@ -41,9 +41,7 @@ class CollectYumPlugin(CollectorPlugin):
         file_name = urllib.parse.unquote(purl.name)
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.namespace}")
 
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-            f"Copying yum package from {purl} to {target_dir}"
-        )
+        self.get_logger().info(f"Copying yum package from {purl} to {target_dir}")
 
         command = [
             self.required_commands[0],
@@ -54,7 +52,7 @@ class CollectYumPlugin(CollectorPlugin):
             file_name,
         ]
 
-        result = self.run_command(command, [])
+        result = self.run_command(command)
         if result.returncode != 0:
             msg = f"Yum failed to copy package to {target_dir}, return_code={result.returncode}"
             self.get_logger().error(msg)
